@@ -938,7 +938,7 @@ AG_TlistBegin(AG_Tlist *tl)
 	     it != TAILQ_END(&tl->items);
 	     it = nit) {
 		nit = TAILQ_NEXT(it, items);
-		if ((!(tl->flags & AG_TLIST_NOSELSTATE) && it->selected) ||
+		if ((!(tl->flags & AG_TLIST_STATELESS) && it->selected) ||
 		      (it->flags & AG_TLIST_HAS_CHILDREN)) {
 			TAILQ_INSERT_HEAD(&tl->selitems, it, selitems);
 		} else {
@@ -1031,7 +1031,7 @@ AG_TlistEnd(AG_Tlist *tl)
 			if (!tl->compare_fn(sit, cit)) {
 				continue;
 			}
-			if (!(tl->flags & AG_TLIST_NOSELSTATE)) {
+			if (!(tl->flags & AG_TLIST_STATELESS)) {
 				cit->selected = sit->selected;
 			}
 			if (sit->flags & AG_TLIST_ITEM_EXPANDED) {
@@ -1073,7 +1073,7 @@ AG_TlistVisibleChildren(AG_Tlist *tl, AG_TlistItem *it)
 }
 
 void
-AG_TlistRefresh(AG_Tlist *_Nonnull tl)
+AG_TlistRefresh(AG_Tlist *tl)
 {
 	AG_OBJECT_ISA(tl, "AG_Widget:AG_Tlist:*");
 	AG_ObjectLock(tl);
@@ -1240,6 +1240,41 @@ AG_TlistMoveToTail(AG_Tlist *tl, AG_TlistItem *it)
 	AG_ObjectUnlock(tl);
 }
 
+/* Copy the contents of tlSrc into tlDst. */
+void
+AG_TlistCopy(AG_Tlist *_Nonnull tlDst, AG_Tlist *_Nonnull tlSrc)
+{
+	AG_TlistItem *itSrc, *itDst;
+
+	AG_OBJECT_ISA(tlDst, "AG_Widget:AG_Tlist:*");
+	AG_OBJECT_ISA(tlSrc, "AG_Widget:AG_Tlist:*");
+
+	AG_ObjectLock(tlDst);
+	AG_ObjectLock(tlSrc);
+
+	TAILQ_FOREACH(itSrc, &tlSrc->items, items) {
+		itDst = AG_TlistAddS(tlDst, itSrc->iconsrc, itSrc->text);
+		itDst->v = itSrc->v;
+		itDst->cat = itSrc->cat;
+		itDst->p1 = itSrc->p1;
+		if (itSrc->color != NULL) {
+			itDst->color = Malloc(sizeof(AG_Color));
+			memcpy(itDst->color, itSrc->color, sizeof(AG_Color));
+		} else {
+			itDst->color = NULL;
+		}
+		itDst->font = itSrc->font;
+		itDst->selected = itSrc->selected;
+		itDst->depth = itSrc->depth;
+		itDst->flags = itSrc->flags;
+		itDst->scale = itSrc->scale;
+		itDst->u = itSrc->u;
+	}
+
+	AG_ObjectUnlock(tlSrc);
+	AG_ObjectUnlock(tlDst);
+}
+
 /* Return a newly allocated and initialized AG_TlistItem */
 AG_TlistItem *
 AG_TlistItemNew(const AG_Surface *icon)
