@@ -95,12 +95,12 @@ const char *agWidgetStateNames[] = {
 AG_WidgetPalette agDefaultPalette = {{
 #if AG_MODEL == AG_MEDIUM           /* --- TrueColor --- */
 {       /* unfocused */
-	{120,120,120,255},          /*             color */
+	{ 70, 70, 70,255},          /*             color */
 	{  0,  0,  0,  0},          /*  background-color */
-	{240,240,240,255},          /*        text-color */
+	{200,200,200,255},          /*        text-color */
 	{ 50, 50, 50,255},          /*        line-color */
-	{144,144,144,255},          /*        high-color */
-	{ 70, 70, 70,255},          /*         low-color */
+	{100,100,100,255},          /*        high-color */
+	{ 60, 60, 60,255},          /*         low-color */
 	{  0,  0, 80,255},          /*   selection-color */
 	{  0,  0,  0,  0}
 }, {
@@ -115,12 +115,12 @@ AG_WidgetPalette agDefaultPalette = {{
 	{  0,  0,  0,  0}
 }, {
 	/* #focused */
-	{140,140,140,255},          /*             color */
+	{100,100,100,255},          /*             color */
 	{  0,  0,  0,  0},          /*  background-color */
 	{240,240,240,255},          /*        text-color */
 	{ 50, 50, 70,255},          /*        line-color */
 	{110,110,110,255},          /*        high-color */
-	{ 70, 70, 70,255},          /*         low-color */
+	{ 60, 60, 60,255},          /*         low-color */
 	{  0,  0,120,255},          /*   selection-color */
 	{  0,  0,  0,  0}
 }, {
@@ -129,20 +129,20 @@ AG_WidgetPalette agDefaultPalette = {{
 	{  0,  0,  0,  0},            /*  background-color */
 	{240,240,240,255},            /*        text-color */
 	{ 50, 50, 50,255},            /*        line-color */
-	{110,110,110,255},            /*        high-color */
-	{ 70, 70, 70,255},            /*         low-color */
+	{120,120,120,255},            /*        high-color */
+	{ 60, 60, 60,255},            /*         low-color */
 	{  0,  0,120,255},            /*   selection-color */
 	{  0,  0,  0,  0}
 },
 #elif AG_MODEL == AG_LARGE                /* --- DeepColor --- */
 {
 	/* unfocused */
-	{0x7878,0x7878,0x7878,0xffff},    /*             color */
+	{0x4646,0x4646,0x4646,0xffff},    /*             color */
 	{0x0000,0x0000,0x0000,0x0000},    /*  background-color */
-	{0xf0f0,0xf0f0,0xf0f0,0xffff},    /*        text-color */
+	{0xc8c8,0xc8c8,0xc8c8,0xffff},    /*        text-color */
 	{0x3232,0x3232,0x3232,0xffff},    /*        line-color */
-	{0x9090,0x9090,0x9090,0xffff},    /*        high-color */
-	{0x4646,0x4646,0x4646,0xffff},    /*         low-color */
+	{0x7878,0x7878,0x7878,0xffff},    /*        high-color */
+	{0x3c3c,0x3c3c,0x3c3c,0xffff},    /*         low-color */
 	{0x0000,0x0000,0x7878,0xffff},    /*   selection-color */
 	{0x0000,0x0000,0x0000,0x0000}
 }, {
@@ -157,12 +157,12 @@ AG_WidgetPalette agDefaultPalette = {{
 	{0x0000,0x0000,0x0000,0x0000}
 }, {
 	/* #focused */
-	{0x8c8c,0x8c8c,0x8c8c,0xffff},    /*             color */
+	{0x6464,0x6464,0x6464,0xffff},    /*             color */
 	{0x0000,0x0000,0x0000,0x0000},    /*  background-color */
 	{0xf0f0,0xf0f0,0xf0f0,0xffff},    /*        text-color */
 	{0x3232,0x3232,0x4646,0xffff},    /*        line-color */
-	{0xaaaa,0xaaaa,0xaaaa,0xffff},    /*        high-color */
-	{0x4646,0x4646,0x4646,0xffff},    /*         low-color */
+	{0x6e6e,0x6e6e,0x6e6e,0xffff},    /*        high-color */
+	{0x3c3c,0x3c3c,0x3c3c,0xffff},    /*         low-color */
 	{0x0000,0x0000,0x7878,0xffff},    /*   selection-color */
 	{0x0000,0x0000,0x0000,0x0000}
 }, {
@@ -171,8 +171,8 @@ AG_WidgetPalette agDefaultPalette = {{
 	{0x0000,0x0000,0x0000,0x0000},    /*  background-color */
 	{0xf0f0,0xf0f0,0xf0f0,0xffff},    /*        text-color */
 	{0x3232,0x3232,0x3232,0xffff},    /*        line-color */
-	{0xaaaa,0xaaaa,0xaaaa,0xffff},    /*        high-color */
-	{0x4646,0x4646,0x4646,0xffff},    /*         low-color */
+	{0x7878,0x7878,0x7878,0xffff},    /*        high-color */
+	{0x3c3c,0x3c3c,0x3c3c,0xffff},    /*         low-color */
 	{0x0000,0x0000,0x7878,0xffff},    /*   selection-color */
 	{0x0000,0x0000,0x0000,0x0000}
 }
